==> ejc-jlcost-impl-3.0.0-20240613.093815-107-sources.jar: com/ejianc/business/jlcost/cost/bean/TargetChangeDetailEntity.java <==
package com.ejianc.business.jlcost.cost.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 成本管理-目标成本-变更子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_cost_target_change_detail")
public class TargetChangeDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="change_id")
    private Long changeId; // 变更主表id
    @TableField(value="source_target_id")
    private Long sourceTargetId; // 原始目标成本主键
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 原始子表主键
    @TableField(value="detail_index")
    private String detailIndex; // 序号
    @TableField(value="code")
    private String code; // 清单编号
    @TableField(value="name")
    private String name; // 清单名称
    @TableField(value="cost_type")
    private Integer costType; // 费用类型：0-材料费（零件） 1-人工费（零件） 2-制作费（产品）3-专项费（产品）4-外协加工费（产品）5-外购产品费（产品）6-现场施工费（项目）7-现场制作费（项目）8-外部设计费（项目）9-运费（项目）10-整体外包费用（项目）11-其他费用（项目）
    @TableField(value="cost_type_name")
    private String costTypeName; // 费用类型名称
    @TableField(value="model")
    private String model; // 型号
    @TableField(value="spec")
    private String spec; // 特征/规格型号
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="before_num")
    private BigDecimal beforeNum; // 变更前数量
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="before_price")
    private BigDecimal beforePrice; // 变更前单价
    @TableField(value="mny")
    private BigDecimal mny; // 金额
    @TableField(value="before_mny")
    private BigDecimal beforeMny; // 变更前金额
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="category_id")
    private Long categoryId; // 分类id
    @TableField(value="category_name")
    private String categoryName; // 分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="parent_id")
    private Long parentId; // 父id
    @TableField(value="leaf_flag")
    private Integer leafFlag; // 是否末级
    @TableField(value="source_id")
    private Long sourceId; // 来源ID
    @TableField(value="source_type")
    private Integer sourceType; // 来源类型0：项目wbs、1：手动新增、2：物料档案
    @TableField(value="row_type")
    private Integer rowType; // 层类型：第一层 1-产品  2-项目费用  第二层 3-零件 4-产品费用  第三层 5-材料 6-人工费    7-其他
    @TableField(value="row_level")
    private Integer rowLevel; // 层级：1-第一层  2-第二层 3-第三层


    //树形相关字段
    @TableField(exist = false)
    private String tid;
    @TableField(exist = false)
    private String tpid;

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getSourceTargetId() {
        return sourceTargetId;
    }

    public void setSourceTargetId(Long sourceTargetId) {
        this.sourceTargetId = sourceTargetId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getCostType() {
        return costType;
    }

    public void setCostType(Integer costType) {
        this.costType = costType;
    }
    public String getCostTypeName() {
        return costTypeName;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }
    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getBeforeNum() {
        return beforeNum;
    }

    public void setBeforeNum(BigDecimal beforeNum) {
        this.beforeNum = beforeNum;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getBeforePrice() {
        return beforePrice;
    }

    public void setBeforePrice(BigDecimal beforePrice) {
        this.beforePrice = beforePrice;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getBeforeMny() {
        return beforeMny;
    }

    public void setBeforeMny(BigDecimal beforeMny) {
        this.beforeMny = beforeMny;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public Integer getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public Integer getRowType() {
        return rowType;
    }

    public void setRowType(Integer rowType) {
        this.rowType = rowType;
    }
    public Integer getRowLevel() {
        return rowLevel;
    }

    public void setRowLevel(Integer rowLevel) {
        this.rowLevel = rowLevel;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }
}

==> ejc-jlcost-impl-3.0.0-20240625.023340-131-sources.jar: com/ejianc/business/jlcost/cost/bean/TargetChangeDetailEntity.java <==
package com.ejianc.business.jlcost.cost.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 成本管理-目标成本-变更子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_cost_target_change_detail")
public class TargetChangeDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="change_id")
    private Long changeId; // 变更主表id
    @TableField(value="source_target_id")
    private Long sourceTargetId; // 原始目标成本主键
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 原始子表主键
    @TableField(value="detail_index")
    private String detailIndex; // 序号
    @TableField(value="code")
    private String code; // 清单编号
    @TableField(value="name")
    private String name; // 清单名称
    @TableField(value="cost_type")
    private Integer costType; // 费用类型：0-材料费（零件） 1-人工费（零件） 2-制作费（产品）3-专项费（产品）4-外协加工费（产品）5-外购产品费（产品）6-现场施工费（项目）7-现场制作费（项目）8-外部设计费（项目）9-运费（项目）10-整体外包费用（项目）11-其他费用（项目）
    @TableField(value="cost_type_name")
    private String costTypeName; // 费用类型名称
    @TableField(value="model")
    private String model; // 型号
    @TableField(value="spec")
    private String spec; // 特征/规格型号
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="before_num")
    private BigDecimal beforeNum; // 变更前数量
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="before_price")
    private BigDecimal beforePrice; // 变更前单价
    @TableField(value="mny")
    private BigDecimal mny; // 金额
    @TableField(value="before_mny")
    private BigDecimal beforeMny; // 变更前金额
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="category_id")
    private Long categoryId; // 分类id
    @TableField(value="category_name")
    private String categoryName; // 分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="parent_id")
    private Long parentId; // 父id
    @TableField(value="leaf_flag")
    private Integer leafFlag; // 是否末级
    @TableField(value="source_id")
    private Long sourceId; // 来源ID
    @TableField(value="source_type")
    private Integer sourceType; // 来源类型0：项目wbs、1：手动新增、2：物料档案
    @TableField(value="row_type")
    private Integer rowType; // 层类型：第一层 1-产品  2-项目费用  第二层 3-零件 4-产品费用  第三层 5-材料 6-人工费    7-其他
    @TableField(value="row_level")
    private Integer rowLevel; // 层级：1-第一层  2-第二层 3-第三层


    //树形相关字段
    @TableField(exist = false)
    private String tid;
    @TableField(exist = false)
    private String tpid;
    //复制子表用
    @TableField(exist = false)
    private Long targetId;

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getSourceTargetId() {
        return sourceTargetId;
    }

    public void setSourceTargetId(Long sourceTargetId) {
        this.sourceTargetId = sourceTargetId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getCostType() {
        return costType;
    }

    public void setCostType(Integer costType) {
        this.costType = costType;
    }
    public String getCostTypeName() {
        return costTypeName;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }
    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getBeforeNum() {
        return beforeNum;
    }

    public void setBeforeNum(BigDecimal beforeNum) {
        this.beforeNum = beforeNum;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getBeforePrice() {
        return beforePrice;
    }

    public void setBeforePrice(BigDecimal beforePrice) {
        this.beforePrice = beforePrice;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getBeforeMny() {
        return beforeMny;
    }

    public void setBeforeMny(BigDecimal beforeMny) {
        this.beforeMny = beforeMny;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public Integer getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public Integer getRowType() {
        return rowType;
    }

    public void setRowType(Integer rowType) {
        this.rowType = rowType;
    }
    public Integer getRowLevel() {
        return rowLevel;
    }

    public void setRowLevel(Integer rowLevel) {
        this.rowLevel = rowLevel;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public Long getTargetId() {
        return targetId;
    }

    public void setTargetId(Long targetId) {
        this.targetId = targetId;
    }
}
